@@ -5,24 +5,40 @@ The classes and functions in this category handle files
 in format "akterm" by German weather service (DWD)
 
 The original columns in dat file specification are:
+
 +-------+--------------------------------------+-------------+
 | entry | description                          | data range  |
 +-------+--------------------------------------+-------------+
 | KENN  | Kennung für das Datenkollektiv       | ``AK``      |
++=======+======================================+=============+
 | STA   | Stationsnummer                       | 00001-99999 |
++-------+--------------------------------------+-------------+
 | JAHR  | Jahr                                 | 1800-2999   |
++-------+--------------------------------------+-------------+
 | MON   | Monat                                | 1-12        |
++-------+--------------------------------------+-------------+
 | TAG   | Tag                                  | 1-31        |
++-------+--------------------------------------+-------------+
 | STUN  | Stunde                               | 0-23        |
++-------+--------------------------------------+-------------+
 | NULL  | --                                   | 0           |
++-------+--------------------------------------+-------------+
 | QDD   | Qualitätsbyte (Windrichtung)         | 0,1,2,9     |
++-------+--------------------------------------+-------------+
 | QFF   | Qualitätsbyte (Windgeschwindigkeit)  | 0,1,2,3,9   |
++-------+--------------------------------------+-------------+
 | DD    | Windrichtung                         | 0-360,999   |
++-------+--------------------------------------+-------------+
 | FF    | Windgeschwindigkeit                  | 0-999       |
++-------+--------------------------------------+-------------+
 | QQ1   | Qualitätsbyte (Wertstatus)           | 0-5,9       |
++-------+--------------------------------------+-------------+
 | KM    | Ausbreitungsklasse nach Klug/Manier  | 1-7,9       |
++-------+--------------------------------------+-------------+
 | QQ2   | Qualitätsbyte (Wertstatus)           | 0,1,9       |
++-------+--------------------------------------+-------------+
 | HM    | Mischungsschichthöhe (m)             | 0-9999      |
++-------+--------------------------------------+-------------+
 | QQ3   | Qualitätsbyte (Wertstatus)           | 0-5,9       |
 +-------+--------------------------------------+-------------+
 | PP    | Niederschlag (SYNOP Code)            | 0-999       |
@@ -218,7 +234,7 @@ class DataFile(object):
                 out[q] = 0
         if prec:
             if 'QPP' not in out.columns:
-                out['QPP'] = 0
+                out['QPP'] = 1
         if 'HM' not in out.columns:
             out['HM'] = -9999.
             out['QQ3'] = 9
@@ -265,7 +281,7 @@ class DataFile(object):
                 try:
                     out[c] = out[c].map(np.round).map(int)
                 except Exception as e:
-                    logging.error('column didnt convert: ' + c)
+                    logging.error('column did not convert: ' + c)
                     raise e
         #
         # reorder columns:
